# Nith_results

[![a srbcheema1 production](https://img.shields.io/badge/-a%20srbcheema1%20production-blue.svg)](https://github.com/srbcheema1)
[![contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.ocm/srbcheema1/Nith_results/issues)
[![Open Source Love](https://badges.frapsoft.com/os/v1/open-source.png?v=103)](https://github.com/srbcheema1/Nith_results)
[![Build Status](https://travis-ci.org/srbcheema1/Nith_results.svg?branch=master)](https://travis-ci.org/srbcheema1/Nith_results)
[![HitCount](http://hits.dwyl.io/srbcheema1/Nith_results.svg)](http://hits.dwyl.io/srbcheema1/Nith_results)

**Nith_results** is a terminal app to extract result of NITH.


### Installation

#### Install using pip (Recommended)

- Use pip to install, user `--user` flag
```
python3 -m pip install --user nith_results
```

#### Build from Source

- Clone the repository and checkout to stable commit
```
git clone https://github.com/srbcheema1/nith_results
cd nith_results
git checkout <latest_version say: v0.0.x>
```

- install requirements
```
python3 -m pip install --user -r requirements.txt
```
- Install nith_results
```
python3 setup.py install --user
```
- Building Source Distribution
```
python3 setup.py sdist
```


### Available Stats

* Results are organised in folders for each branch in [result directory](https://github.com/srbcheema1/Nith_results/tree/master/result)
* Branch wise results are present in folders named with branch with files as `batch_xx_xgpi.txt` or `batch_xx_xgpi.json`.
* Full Year-wise and Full college wise results are also available in folders [FULL_YEAR](https://github.com/srbcheema1/Nith_results/tree/master/result/json/FULL_YEAR) and [FULL_COLLEGE](https://github.com/srbcheema1/Nith_results/tree/master/result/json/FULL_COLLEGE) respectively.
* Result is available in text and json format in [result/text](https://github.com/srbcheema1/Nith_results/tree/master/result/text) and [result/json](https://github.com/srbcheema1/Nith_results/tree/master/result/json) directories respectively


* Folders contain results in `branch_name_xx_xgpi.txt`.
* Also you can find out `full_year_xx_xgpi.txt` containing data for whole year.


### Contact / Social Media

[![Github](https://raw.githubusercontent.com/srbcheema1/CheemaFy/master/myPlugins/extra_things/png_images/social/github.png)](https://github.com/srbcheema1/)
[![LinkedIn](https://raw.githubusercontent.com/srbcheema1/CheemaFy/master/myPlugins/extra_things/png_images/social/linkedin-48x48.png)](https://www.linkedin.com/in/srbcheema1/)
[![Facebook](https://raw.githubusercontent.com/srbcheema1/CheemaFy/master/myPlugins/extra_things/png_images/social/fb.png)](https://www.facebook.com/srbcheema/)


### Development by

Developer / Author: [Srb Cheema](https://github.com/srbcheema1/)

